@@ -14,7 +14,7 @@ use FindBin qw/$Bin/;
 use Path::Class;
 use base qw/Exporter/;
 
-our $VERSION = 0.3;
+our $VERSION = 0.4;
 our ($name)  = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
 our $tmux_conf    = file "$ENV{HOME}", '.tmux.conf';
 our $tmux_layout  = dir "$ENV{HOME}", '.tmux', 'layout';
@@ -36,7 +36,7 @@ sub run {
         'verbose|v+',
         'man',
         'help',
-        'VERSION!',
+        'version!',
     );
 
     if ( !$success && !$option{auto} ) {
@@ -208,7 +208,7 @@ App::Devmode2 - A tmux session loading tool
 
 =head1 VERSION
 
-This documentation refers to App::Devmode2 version 0.3
+This documentation refers to App::Devmode2 version 0.4
 
 =head1 SYNOPSIS
 
@@ -224,6 +224,11 @@ This documentation refers to App::Devmode2 version 0.3
    -C --curdir  Saves the current director as the directory to change to
                 when next loaded. (implies --save)
 
+   -v --verbose Show more verbose output
+      --man     Show full help documentation
+      --help    Show this
+      --version Show the version of devmode2
+
 =head1 DESCRIPTION
 
 C<devmode2> is a helper script for L<tmux> to simplify the creation and
@@ -253,6 +258,13 @@ optionally saves that config.
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
+Bash auto completion helper (add to your C<~/.bashrc> file:
+
+    _devmode2() {
+        COMPREPLY=($(devmode2 --auto --current "${COMP_CWORD}" -- ${COMP_WORDS[@]}))
+    }
+    complete -F _devmode2 devmode2
+
 =head1 DEPENDENCIES
 
 =head1 INCOMPATIBILITIES
